@@ -3,16 +3,16 @@ from pathlib import Path
 from datetime import datetime
 
 class logger:
-    def __init__(self, filename=None, max_filesize=1024):
+    def __init__(self, filename=None, max_filesize=50140):
         if not filename:
-            filename = Path(sys.argv[0]).stem + '.log'
+            filename = Path(sys.argv[0]).stem + '.txt'
         self.filename = filename
         self.max_filesize = max_filesize
 
         logger = logging.getLogger(__name__)
         logger.setLevel(logging.DEBUG)
 
-        log_file = logging.FileHandler(filename, mode='w')
+        log_file = logging.FileHandler(filename, mode='w', encoding='utf-8')
         log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
         log_file.setFormatter(log_format)
         logger.addHandler(log_file)
